@@ -8,18 +8,17 @@ from elementary.config.config import Config
 from elementary.tracking.anonymous_tracking import AnonymousTracking
 from elementary.utils.log import get_logger
 
-f = Figlet(font='slant')
-click.echo(f.renderText('Elementary'))
+f = Figlet(font="slant")
+click.echo(f.renderText("Elementary"))
 elementary.cli.upgrade.recommend_version_upgrade()
 
-root_folder = os.path.join(os.path.dirname(__file__), '..')
-modules = ['monitor']
+root_folder = os.path.join(os.path.dirname(__file__), "..")
+modules = ["monitor"]
 
 logger = get_logger(__name__)
 
 
 class ElementaryCLI(click.MultiCommand):
-
     def list_commands(self, ctx):
         rv = []
         for module in modules:
@@ -29,10 +28,10 @@ class ElementaryCLI(click.MultiCommand):
 
     def get_command(self, ctx, name):
         ns = {}
-        fn = os.path.join(root_folder, name, 'cli.py')
+        fn = os.path.join(root_folder, name, "cli.py")
         try:
             with open(fn) as f:
-                code = compile(f.read(), fn, 'exec')
+                code = compile(f.read(), fn, "exec")
                 eval(code, ns, ns)
         except Exception:
             logger.debug(f'Unable to load the "{name}" module.', exc_info=True)
@@ -41,7 +40,7 @@ class ElementaryCLI(click.MultiCommand):
 
     def format_help(self, ctx, formatter):
         try:
-            click.echo('Loading dependencies (this might take a few seconds)')
+            click.echo("Loading dependencies (this might take a few seconds)")
             AnonymousTracking(config=Config()).track_cli_help()
         except Exception:
             pass
@@ -51,7 +50,9 @@ class ElementaryCLI(click.MultiCommand):
         self.format_epilog(ctx, formatter)
 
 
-cli = ElementaryCLI(help='Open source data reliability solution (https://docs.elementary-data.com/)')
+cli = ElementaryCLI(
+    help="Open source data reliability solution (https://docs.elementary-data.com/)"
+)
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
