@@ -1,6 +1,5 @@
 import json
 from abc import ABC, abstractmethod
-import time
 from typing import Optional, List
 
 from slack_sdk import WebClient, WebhookClient
@@ -24,7 +23,7 @@ class SlackClient(ABC):
         self._initial_retry_handlers()
 
     @staticmethod
-    def create_client(config: Config) -> Optional['SlackClient']:
+    def create_client(config: Config) -> Optional["SlackClient"]:
         if not config.has_slack:
             return None
         if config.slack_token:
@@ -45,7 +44,9 @@ class SlackClient(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def send_file(self, channel_name: str, file_path: str, message: SlackMessageSchema) -> bool:
+    def send_file(
+        self, channel_name: str, file_path: str, message: SlackMessageSchema
+    ) -> bool:
         raise NotImplementedError
 
     @abstractmethod
@@ -57,13 +58,17 @@ class SlackWebClient(SlackClient):
     def _initial_client(self):
         return WebClient(token=self.token)
 
-    def send_message(self, channel_name: str, message: SlackMessageSchema, **kwargs) -> bool:
+    def send_message(
+        self, channel_name: str, message: SlackMessageSchema, **kwargs
+    ) -> bool:
         try:
             self.client.chat_postMessage(
                 channel=channel_name,
                 text=message.text,
                 blocks=json.dumps(message.blocks) if message.blocks else None,
-                attachments=json.dumps(message.attachments) if message.attachments else None
+                attachments=json.dumps(message.attachments)
+                if message.attachments
+                else None,
             )
             return True
         except SlackApiError as err:
@@ -71,12 +76,16 @@ class SlackWebClient(SlackClient):
                 return self.send_message(channel_name, message)
             return False
 
-    def send_file(self, channel_name: str, file_path: str, message: SlackMessageSchema) -> bool:
+    def send_file(
+        self, channel_name: str, file_path: str, message: SlackMessageSchema
+    ) -> bool:
+        channel_id = self._get_channel_id(channel_name)
         try:
-            self.client.files_upload(
-                channels=channel_name,
+            self.client.files_upload_v2(
+                channel=channel_id,
                 initial_comment=message.text,
-                file=file_path
+                file=file_path,
+                request_file_info=False,
             )
             return True
         except SlackApiError as err:
@@ -88,12 +97,12 @@ class SlackWebClient(SlackClient):
         send_succeed = self.send_file(
             channel_name=channel,
             file_path=report_file_path,
-            message=SlackMessageSchema(text="Elementary monitoring report")
+            message=SlackMessageSchema(text="Elementary monitoring report"),
         )
         if send_succeed:
-            logger.info('Sent report to Slack.')
+            logger.info("Sent report to Slack.")
         else:
-            logger.error('Failed to send report to Slack.')
+            logger.error("Failed to send report to Slack.")
         return send_succeed
 
     def _get_channel_id(self, channel_name: str) -> Optional[str]:
@@ -101,14 +110,16 @@ class SlackWebClient(SlackClient):
             available_channels = self._get_channels()
             available_channel_names = []
             for available_channel in available_channels:
-                available_channel_name = available_channel['name']
+                available_channel_name = available_channel["name"]
                 available_channel_names.append(available_channel_name)
                 if available_channel_name == channel_name:
-                    return available_channel['id']
-            logger.error(f'Channel {channel_name} not found. Available channels: {available_channel_names}')
+                    return available_channel["id"]
+            logger.error(
+                f"Channel {channel_name} not found. Available channels: {available_channel_names}"
+            )
             return None
         except Exception:
-            logger.error(f'Elementary app failed to query Slack channels.')
+            logger.error(f"Elementary app failed to query Slack channels.")
             return None
 
     def _join_channel(self, channel_id: str) -> bool:
@@ -125,53 +136,61 @@ class SlackWebClient(SlackClient):
             has_more = True
             cursor = None
             while has_more:
-                response = self.client.conversations_list(cursor=cursor, types='public_channel,private_channel',
-                                                          exclude_archived=True)
+                response = self.client.conversations_list(
+                    cursor=cursor,
+                    types="public_channel,private_channel",
+                    exclude_archived=True,
+                )
                 channels.extend(response["channels"])
                 cursor = response.get("response_metadata", {}).get("next_cursor")
                 has_more = True if cursor else False
             return channels
         except SlackApiError as e:
-            logger.error(f"Elementary app failed to query all Slack public channels. Error: {e}")
+            logger.error(
+                f"Elementary app failed to query all Slack public channels. Error: {e}"
+            )
             return []
 
     def _handle_send_err(self, err: SlackApiError, channel_name: str) -> bool:
-        err_type = err.response.data['error']
-        if err_type == 'not_in_channel':
-            logger.info('Elementary app is not in the channel. Attempting to join.')
+        err_type = err.response.data["error"]
+        if err_type == "not_in_channel":
+            logger.info("Elementary app is not in the channel. Attempting to join.")
             channel_id = self._get_channel_id(channel_name)
             if not channel_id:
                 return False
             return self._join_channel(channel_id=channel_id)
-        elif err_type == 'channel_not_found':
+        elif err_type == "channel_not_found":
             logger.error(
-                f'Channel {channel_name} was not found by the Elementary app. Please add the app to the channel.')
+                f"Channel {channel_name} was not found by the Elementary app. Please add the app to the channel."
+            )
             return False
-        logger.error(f"Failed to send a message to channel - {channel_name}. Error: {err}")
+        logger.error(
+            f"Failed to send a message to channel - {channel_name}. Error: {err}"
+        )
         return False
 
 
 class SlackWebhookClient(SlackClient):
     def _initial_client(self):
-        return WebhookClient(url=self.webhook, default_headers={"Content-type": "application/json"})
+        return WebhookClient(
+            url=self.webhook, default_headers={"Content-type": "application/json"}
+        )
 
     def send_message(self, message: SlackMessageSchema, **kwargs) -> bool:
         response = self.client.send(
-            text=message.text,
-            blocks=message.blocks,
-            attachments=message.attachments
+            text=message.text, blocks=message.blocks, attachments=message.attachments
         )
         if response.status_code == OK_STATUS_CODE:
             return True
 
         else:
-            logger.error(f"Could not post message to slack via webhook - {self.webhook}. Error: {response.body}")
+            logger.error(
+                f"Could not post message to slack via webhook - {self.webhook}. Error: {response.body}"
+            )
             return False
 
     def send_file(self, **kwargs):
-        logger.error("Slack webhook does not support sending files."
-                     "Please use Slack token instead (see documentation on how to configure a slack token)")
+        raise NotImplementedError
 
     def send_report(self, **kwargs):
-        logger.error("Slack webhook does not support sending reports."
-                     "Please use Slack token instead (see documentation on how to configure a slack token)")
+        raise NotImplementedError
